img processor for augmentation and resizing, to expand image variety before start DL phase.

<!-- ``` -->
<!-- #setup.py can be found => to make this package available in local env  -->
<!-- pip install -e . -->
<!-- ``` -->
<!--  -->
<!-- ```Python -->
<!-- # from aug_img.imgaug import Processor -->
<!-- # x= Processor("img/img.jpg") -->
<!-- # x.resize(1000, "roi.jpg") -->
<!-- ``` -->
<!--  -->
<!-- ``` -->
<!-- #upload to PYPI -->
<!--  -->
<!--  -->
<!-- ``` -->
<!--  -->
